# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_service.api.api_rds_connection_tests_api import ApiRdsConnectionTestsApi


class TestApiRdsConnectionTestsApi(unittest.TestCase):
    """ApiRdsConnectionTestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApiRdsConnectionTestsApi()

    def tearDown(self) -> None:
        pass

    def test_get(self) -> None:
        """Test case for get

        """
        pass

    def test_post(self) -> None:
        """Test case for post

        Dispatch RDS connection tests
        """
        pass


if __name__ == '__main__':
    unittest.main()
